package com.qs.mp.user.service.impl;

import com.qs.mp.common.enums.DeliverOrderStatusEnum;
import com.qs.mp.pay.domain.PayOrder;
import com.qs.mp.system.service.id.BizIdGenerator;
import com.qs.mp.user.domain.UserAddr;
import com.qs.mp.user.domain.UserDeliverOrder;
import com.qs.mp.user.domain.vo.DeliverOrderSettleVO;
import com.qs.mp.user.mapper.UserDeliverOrderMapper;
import com.qs.mp.user.service.IUserDeliverOrderService;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

/**
 * <p>
 * 用户提货订单 服务实现类
 * </p>
 *
 * @author quanshu
 * @since 2022-03-07
 */
@Service
public class UserDeliverOrderServiceImpl extends ServiceImpl<UserDeliverOrderMapper, UserDeliverOrder> implements IUserDeliverOrderService {

  @Autowired
  private BizIdGenerator bizIdGenerator;

  @Override
  @Transactional
  public String submitOrder(Long userId, DeliverOrderSettleVO orderSettleVO) {
    UserDeliverOrder userDeliverOrder = new UserDeliverOrder();
    userDeliverOrder.setOrderId(bizIdGenerator.newId());
    userDeliverOrder.setUserId(userId);
    UserAddr userAddr = orderSettleVO.getAddr();
    userDeliverOrder.setReceiver(userAddr.getReceiver());
    userDeliverOrder.setTel(userAddr.getMobile());
    userDeliverOrder.setProvince(userAddr.getProvince());
    userDeliverOrder.setCity(userAddr.getCity());
    userDeliverOrder.setArea(userAddr.getArea());
    userDeliverOrder.setAddress(userAddr.getAddr());
    userDeliverOrder.setOrderNum(orderSettleVO.getPrizeList().size());
    userDeliverOrder.setPayAmt(orderSettleVO.getPayAmt());
    userDeliverOrder.setFreightAmt(orderSettleVO.getFreightAmt());
    userDeliverOrder.setMemo(null);
    if (orderSettleVO.getPayAmt() > 0) {
      userDeliverOrder.setStatus(DeliverOrderStatusEnum.NOT_PAY);
    } else {
      userDeliverOrder.setStatus(DeliverOrderStatusEnum.NOT_DELIVER);
    }
    save(userDeliverOrder);


    return userDeliverOrder.getOrderId();
  }

  @Override
  public boolean cancelOrder(String orderId) {
    return false;
  }

  @Override
  public boolean paySuccess(PayOrder payOrder) {
    return false;
  }
}
